aboutsummaryrefslogtreecommitdiff
path: root/sys/pci
diff options
context:
space:
mode:
authorMike Smith <msmith@FreeBSD.org>1999-01-16 00:36:53 +0000
committerMike Smith <msmith@FreeBSD.org>1999-01-16 00:36:53 +0000
commit38c9282d5c52610d324839a8d31539cf8531f60d (patch)
treef2e824733d28e6626e3e8d1f12d33a858a5199e9 /sys/pci
parent2e03cdebd586c7afbec50556ed31d29aff685307 (diff)
downloadsrc-38c9282d5c52610d324839a8d31539cf8531f60d.tar.gz
src-38c9282d5c52610d324839a8d31539cf8531f60d.zip
Fix breakage in rev 1.19; the second argument to ide_pci_candma is a
controller number, not a unit number. Make this clear.
Notes
Notes: svn path=/head/; revision=42709
Diffstat (limited to 'sys/pci')
-rw-r--r--sys/pci/ide_pci.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/pci/ide_pci.c b/sys/pci/ide_pci.c
index 14378e1b6bc7..0d1f1feb20a4 100644
--- a/sys/pci/ide_pci.c
+++ b/sys/pci/ide_pci.c
@@ -26,7 +26,7 @@
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: ide_pci.c,v 1.22 1999/01/12 01:36:46 eivind Exp $
+ * $Id: ide_pci.c,v 1.23 1999/01/13 04:40:50 julian Exp $
*/
#include "pci.h"
@@ -1450,16 +1450,16 @@ static struct pci_device ide_pci_device = {
DATA_SET(pcidevice_set, ide_pci_device);
/*
* Return a cookie if we can do DMA on the specified (iobase_wd, unit).
*/
static void *
-ide_pci_candma(int iobase_wd, int unit)
+ide_pci_candma(int iobase_wd, int ctrlr)
{
struct ide_pci_cookie *cp;
cp = softc.cookies.lh_first;
while(cp) {
- if (cp->unit == unit &&
+ if (cp->ctrlr == ctrlr &&
((iobase_wd == 0) || (cp->iobase_wd == iobase_wd)))
break;
cp = cp->le.le_next;
@@ -1450,16 +1450,16 @@ static struct pci_device ide_pci_device = {
DATA_SET(pcidevice_set, ide_pci_device);
/*
- * Return a cookie if we can do DMA on the specified (iobase_wd, unit).
+ * Return a cookie if we can do DMA on the specified (iobase_wd, ctrlr).
*/
static void *